==> nCal_0.1-1.tar.gz: nCal/man/plot.bcrm.Rd <==
\name{plot.bcrm}
\alias{plot.bcrm}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Plot function for the bcrm object
}
\description{
Plot function for the bcrm object
}
\usage{
\method{plot}{bcrm} (x, assay_id = NULL, add = FALSE, lcol = 1, main = NULL, x2 = NULL, 
    lwd = 0.1, points.only = FALSE, all.lines.only = FALSE, t = NULL, ylim = NULL, 
    same.ylim = FALSE, lty3 = NULL, x3 = NULL, lcol2 = NULL, lcol3 = NULL, xlab = NULL,
    ylab = NULL, col.outliers = TRUE, lty = 1, cex = 1, log = "x", ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{
%%     ~~Describe \code{x} here~~
}
  \item{assay_id}{
%%     ~~Describe \code{assay_id} here~~
}
  \item{add}{
%%     ~~Describe \code{add} here~~
}
  \item{lcol}{
%%     ~~Describe \code{lcol} here~~
}
  \item{main}{
%%     ~~Describe \code{main} here~~
}
  \item{x2}{
%%     ~~Describe \code{x2} here~~
}
  \item{lwd}{
%%     ~~Describe \code{lwd} here~~
}
  \item{points.only}{
%%     ~~Describe \code{points.only} here~~
}
  \item{all.lines.only}{
%%     ~~Describe \code{all.lines.only} here~~
}
  \item{t}{
%%     ~~Describe \code{t} here~~
}
  \item{ylim}{
%%     ~~Describe \code{ylim} here~~
}
  \item{same.ylim}{
%%     ~~Describe \code{same.ylim} here~~
}
  \item{lty3}{
%%     ~~Describe \code{lty3} here~~
}
  \item{x3}{
%%     ~~Describe \code{x3} here~~
}
  \item{lcol2}{
%%     ~~Describe \code{lcol2} here~~
}
  \item{lcol3}{
%%     ~~Describe \code{lcol3} here~~
}
  \item{xlab}{
%%     ~~Describe \code{xlab} here~~
}
  \item{ylab}{
%%     ~~Describe \code{ylab} here~~
}
  \item{col.outliers}{
%%     ~~Describe \code{col.outliers} here~~
}
  \item{lty}{
%%     ~~Describe \code{lty} here~~
}
  \item{cex}{
%%     ~~Describe \code{cex} here~~
}
  \item{log}{
%%     ~~Describe \code{log} here~~
}
  \item{\dots}{
%%     ~~Describe \code{\dots} here~~
}
}

==> nCal_0.2-1.tar.gz: nCal/man/plot.bcrm.Rd <==
\name{plot.bcrm}
\alias{plot.bcrm}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Plot function for the bcrm object
}
\description{
Plot function for the bcrm object
}
\usage{
\method{plot}{bcrm} (x, assay_id = NULL, add = FALSE, lcol = 1, main = NULL, fit.2 = NULL, 
    lwd = 0.1, points.only = FALSE, all.lines.only = FALSE, t = NULL, ylim = NULL, 
    same.ylim = FALSE, lty3 = NULL, fit.3 = NULL, lcol2 = NULL, lcol3 = NULL, xlab = NULL,
    ylab = NULL, col.outliers = TRUE, lty = 1, cex = 1, log = "x", ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{
%%     ~~Describe \code{x} here~~
}
  \item{assay_id}{
%%     ~~Describe \code{assay_id} here~~
}
  \item{add}{
%%     ~~Describe \code{add} here~~
}
  \item{lcol}{
%%     ~~Describe \code{lcol} here~~
}
  \item{main}{
%%     ~~Describe \code{main} here~~
}
  \item{fit.2}{
%%     ~~Describe \code{fit.2} here~~
}
  \item{lwd}{
%%     ~~Describe \code{lwd} here~~
}
  \item{points.only}{
%%     ~~Describe \code{points.only} here~~
}
  \item{all.lines.only}{
%%     ~~Describe \code{all.lines.only} here~~
}
  \item{t}{
%%     ~~Describe \code{t} here~~
}
  \item{ylim}{
%%     ~~Describe \code{ylim} here~~
}
  \item{same.ylim}{
%%     ~~Describe \code{same.ylim} here~~
}
  \item{lty3}{
%%     ~~Describe \code{lty3} here~~
}
  \item{fit.3}{
%%     ~~Describe \code{fit.3} here~~
}
  \item{lcol2}{
%%     ~~Describe \code{lcol2} here~~
}
  \item{lcol3}{
%%     ~~Describe \code{lcol3} here~~
}
  \item{xlab}{
%%     ~~Describe \code{xlab} here~~
}
  \item{ylab}{
%%     ~~Describe \code{ylab} here~~
}
  \item{col.outliers}{
%%     ~~Describe \code{col.outliers} here~~
}
  \item{lty}{
%%     ~~Describe \code{lty} here~~
}
  \item{cex}{
%%     ~~Describe \code{cex} here~~
}
  \item{log}{
%%     ~~Describe \code{log} here~~
}
  \item{\dots}{
%%     ~~Describe \code{\dots} here~~
}
}
